@@ -10,7 +10,7 @@ function summary = doctest_collect(w, directives, summary, recursive, verbose, d
 %%
 % Copyright (c) 2010 Thomas Grenfell Smith
 % Copyright (c) 2015 Michael Walter
-% Copyright (c) 2015-2019, 2022 Colin B. Macdonald
+% Copyright (c) 2015-2019, 2022-2025 Colin B. Macdonald
 % Copyright (c) 2015 Oliver Heimlich
 % Copyright (C) 2018 Mike Miller
 % SPDX-License-Identifier: BSD-3-Clause
@@ -278,7 +278,7 @@ function targets = collect_targets_class(w, depth)
     w = w(2:end);
   end
 
-  % workaround github.com/catch22/octave-doctest/issues/135 by
+  % workaround github.com/gnu-octave/octave-doctest/issues/135 by
   % accessing all non-constructor method help text *before* "help obj"
   if (is_octave () && compare_versions (OCTAVE_VERSION, '7.0.0', '<'))
     meths = methods (w);
@@ -309,10 +309,14 @@ function targets = collect_targets_class(w, depth)
   for i=1:numel(meths)
     target = struct();
     if is_octave()
-      if compare_versions (OCTAVE_VERSION, '7.0.0', '>=') && exist (w, "class") == 8
+      if compare_versions (OCTAVE_VERSION, '9.0.0', '>=') && exist (w, "class") == 8
         % classdef on newish Octave: use cls.method
+        target.name = sprintf ('%s.%s', w, meths{i});
+        target.link = '';
+      elseif compare_versions (OCTAVE_VERSION, '7.0.0', '>=') && exist (w, "class") == 8
+        % use cls.method, use cls.method, but skip cls.cls
         if strcmp (meths{i}, w)
-          % TODO: gathering the ctor help fails https://savannah.gnu.org/bugs/?62803
+          % gathering the ctor help fails https://savannah.gnu.org/bugs/?62803
           continue
         end
         target.name = sprintf ('%s.%s', w, meths{i});
@@ -373,8 +377,12 @@ function [docstring, error] = extract_docstring(name)
       assert (isempty (docstring))
       error = '';
     elseif strcmp(format, 'Not found')
-      % looks like "doctest test_no_docs.m" gets us here: octave bug?
       if (regexp(name,'\.m$'))
+        % looks like "doctest test_no_docs.m" gets us here: octave bug?
+        assert (isempty (docstring))
+        error = '';
+      elseif (is_octave() && compare_versions (OCTAVE_VERSION(), '9.0.0', '>=') && regexp(name,'.+\.delete$'))
+        % forgive mssing "classdef.delete", which Octave 9 "methods" adds to handle-classes
         assert (isempty (docstring))
         error = '';
       else
